pub struct XlogLayer { /* private fields */ }Expand description
tracing-subscriber layer that forwards events to a Xlog instance.
Implementations
Sourceimpl XlogLayer
impl XlogLayer
Sourcepub fn new(logger: Xlog) -> (Self, XlogLayerHandle)
pub fn new(logger: Xlog) -> (Self, XlogLayerHandle)
Build a layer using the logger’s current level and defaults.
Sourcepub fn with_config(
logger: Xlog,
config: XlogLayerConfig,
) -> (Self, XlogLayerHandle)
pub fn with_config( logger: Xlog, config: XlogLayerConfig, ) -> (Self, XlogLayerHandle)
Build a layer from explicit configuration.
This only configures layer-side filtering and does not mutate the underlying logger’s level.
Sourcepub fn handle(&self) -> XlogLayerHandle
pub fn handle(&self) -> XlogLayerHandle
Create a new handle that can be used to reconfigure the layer.